@@ -103,7 +103,7 @@ check_staged_changes <- function(path, custom_message = "this function") {
   } else {
     # Format files
     files_staged <- as.character(git_status$staged)
-    files_staged <- file.path(git2r_workdir(r), files_staged)
+    files_staged <- file.path(git2r::workdir(r), files_staged)
     files_staged <- relative(files_staged)
     files_staged <- utils::capture.output(dput(files_staged))
     stop(wrap(
@@ -117,27 +117,49 @@ check_staged_changes <- function(path, custom_message = "this function") {
 
 # Obtain all the committed files in a Git repository at a given commit.
 #
+# repo - a git_repository object
+#
+# commit - NULL (default) or a git_commit object
+#
+# sysgit - character (default: `Sys.which("git")`) Path to system Git executable
+#          used to obtain committed files via `git ls-files`. Cannot be used
+#          with commit argument. To disable, set `git = ""`.
+#
 # The default is to use the head commit.
 #
 # Returns absolute paths.
-get_committed_files <- function(repo, commit = NULL) {
+get_committed_files <- function(repo, commit = NULL,
+                                sysgit = getOption("workflowr.sysgit", default = "")) {
+  stopifnot(identical(class(repo), "git_repository"))
+  stopifnot(is.null(commit) || identical(class(commit), "git_commit"))
+
   n_commits <- length(git2r::commits(repo))
   if (n_commits == 0) {
     return(NA)
   }
-  if (is.null(commit)) {
-    commit <- git2r::lookup(repo, git2r::branch_target(git2r_head(repo)))
+
+  # If Git is available and don't need a specific commit, use `git ls-files`
+  if (!is.null(sysgit) && !is.na(sysgit) && nchar(sysgit) > 0 && is.null(commit)) {
+    cmd <- sprintf("%s -C %s ls-files", sysgit, git2r::workdir(repo))
+    files <- system(cmd, intern = TRUE)
+    files <- absolute(file.path(git2r::workdir(repo), files))
+    return(files)
   }
+
+  if (is.null(commit)) {
+    commit <- git2r::lookup(repo, git2r::branch_target(git2r::repository_head(repo)))
+  }
+
   tree <- git2r::tree(commit)
   files <- ls_files(tree)
-  files <- absolute(file.path(git2r_workdir(repo), files))
+  files <- absolute(file.path(git2r::workdir(repo), files))
   return(files)
 }
 
 # List all files in a given "git_tree" object.
 ls_files <- function (tree) {
-  tree_list <- git2r_as.list(tree)
-  tree_df <-git2r_as.data.frame(tree)
+  tree_list <- as.list(tree)
+  tree_df <- as.data.frame(tree)
   names(tree_list) <- tree_df$name
   files <- tree_df$name[tree_df$type == "blob"]
   dirs <- tree_df$name[tree_df$type == "tree"]
@@ -165,29 +187,21 @@ get_outdated_files <- function(repo, files, outdir = NULL) {
     stop("Only R Markdown files are accepted.")
   # Corresponding HTML files
   html <- to_html(files, outdir = outdir)
-  # Remove preceding path if necessary. Has to be relative to .git directory.
-  path_to_git <- paste0(git2r_workdir(repo), "/")
-  files <- stringr::str_replace(files, path_to_git, "")
-  html <- stringr::str_replace(html, path_to_git, "")
   # For each source file, determine if it has been committed more recently than
   # its corresponding HTML
   out_of_date <- logical(length = length(files))
 
-  blobs <- git2r::odb_blobs(repo)
-  blobs$fname <- ifelse(blobs$path == "", blobs$name,
-                        file.path(blobs$path, blobs$name))
-
   for (i in seq_along(files)) {
     # Most recent commit time of source and HTML files
-    recent_source <- max(blobs$when[blobs$fname == files[i]])
-    recent_html <- max(blobs$when[blobs$fname == html[i]])
-    if (recent_source >= recent_html) {
+    recent_source <- git2r::commits(repo, n = 1, path = files[i])[[1]]
+    recent_source_time <- as.POSIXct(recent_source$author$when)
+    recent_html <- git2r::commits(repo, n = 1, path = html[i])[[1]]
+    recent_html_time <- as.POSIXct(recent_html$author$when)
+    if (recent_source_time >= recent_html_time) {
       out_of_date[i] <- TRUE
     }
   }
   outdated <- files[out_of_date]
-  # Prepend path to Git repository
-  outdated <- file.path(path_to_git, outdated)
   return(outdated)
 }
 
@@ -220,16 +234,16 @@ obtain_files_in_commit <- function(repo, commit) {
   if (length(parent_commit) == 0) {
     files <- obtain_files_in_commit_root(repo, commit)
   } else if (length(parent_commit) == 1) {
-    git_diff <- git2r_diff(git2r::tree(commit),
+    git_diff <- base::diff(git2r::tree(commit),
                             git2r::tree(parent_commit[[1]]))
-    files <- sapply(git2r_slot(git_diff, "files"),
-                    function(x) git2r_slot(x, "new_file"))
+    files <- sapply(git_diff$files,
+                    function(x) x$new_file)
   } else {
     stop(sprintf("Cannot perform diff on commit %s because it has %d parents",
-                 git2r_slot(commit, "sha"), length(parent_commit)))
+                 commit$sha, length(parent_commit)))
   }
 
-  files <- absolute(file.path(git2r_workdir(repo), files))
+  files <- absolute(file.path(git2r::workdir(repo), files))
   return(files)
 }
 
@@ -250,7 +264,7 @@ obtain_files_in_commit_root <- function(repo, commit) {
   stopifnot(class(repo) ==  "git_repository",
             class(commit) == "git_commit",
             length(git2r::parents(commit)) == 0)
-  entries <- git2r_as.data.frame(git2r::tree(commit))
+  entries <- as.data.frame(git2r::tree(commit))
   files <- character()
   while (nrow(entries) > 0) {
     if (entries$type[1] == "blob") {
@@ -265,7 +279,7 @@ obtain_files_in_commit_root <- function(repo, commit) {
       #  - add the subdirectory to the name so that path is correct
       #  - remove the entry from beginning and add new entries to end of
       #    data.frame
-      new_tree_df <- git2r_as.data.frame(git2r::lookup(repo, entries$sha[1]))
+      new_tree_df <- as.data.frame(git2r::lookup(repo, entries$sha[1]))
       new_tree_df$name <- file.path(entries$name[1], new_tree_df$name)
       entries <- rbind(entries[-1, ], new_tree_df)
     } else {
@@ -332,13 +346,13 @@ check_remote <- function(remote, remote_avail) {
 # Returns a list of length two.
 determine_remote_and_branch <- function(repo, remote, branch) {
   stopifnot(class(repo) == "git_repository")
-  git_head <- git2r_head(repo)
+  git_head <- git2r::repository_head(repo)
   tracking <- git2r::branch_get_upstream(git_head)
   # If both remote and branch are NULL and the current branch is tracking a
   # remote branch, use this remote and branch.
   if (is.null(remote) && is.null(branch) && !is.null(tracking)) {
     remote <- git2r::branch_remote_name(tracking)
-    branch <- stringr::str_split_fixed(git2r_slot(tracking, "name"),
+    branch <- stringr::str_split_fixed(tracking$name,
                                        "/", n = 2)[, 2]
   }
   # If remote is NULL, take an educated guess at what the user would want.
@@ -347,7 +361,7 @@ determine_remote_and_branch <- function(repo, remote, branch) {
   }
   # If branch is NULL, use the same name as the current branch.
   if (is.null(branch)) {
-    branch <- git2r_slot(git_head, "name")
+    branch <- git_head$name
   }
 
   return(list(remote = remote, branch = branch))
@@ -487,7 +501,7 @@ authenticate_git <- function(protocol, username = NULL,
 check_git_lock <- function(r) {
   stopifnot(class(r) == "git_repository")
 
-  index_lock <- file.path(git2r_workdir(r), ".git/index.lock")
+  index_lock <- file.path(git2r::workdir(r), ".git/index.lock")
   if (fs::file_exists(index_lock)) {
     stop(call. = FALSE, wrap(
       "The Git repository is locked. This can happen if a Git command
