@@ -219,7 +219,7 @@ print.wflow_remove <- function(x, ...) {
     } else {
       cat("\n", wrap(sprintf(
         "The following was removed from the Git repo in commit %s:",
-        stringr::str_sub(git2r_slot(x$commit, "sha"), start = 1, end = 7))),
+        stringr::str_sub(x$commit$sha, start = 1, end = 7))),
         "\n\n", sep = "")
     }
     cat(x$files_git, sep = "\n")
