@@ -3,9 +3,11 @@
 #' \code{wflow_use_gitlab} automates all the local configuration necessary to
 #' deploy your workflowr project with
 #' \href{https://docs.gitlab.com/ee/ci/yaml/README.html#pages}{GitLab Pages}.
-#' However, you will need to manually login to your account and create the new
-#' repository on GitLab. The final step is to run \code{wflow_git_push} in the R
-#' console.
+#' Afterwards, you will need to run \code{wflow_git_push} in the R console (or
+#' \code{git push} in the terminal) to push the code to GitLab. Note that this
+#' will also create the repository if it doesn't exist yet (this requires GitLab
+#' 10.5 or greater). Alternatively, you could manually login to your account and
+#' create the new repository on GitLab prior to pushing.
 #'
 #' \code{wflow_use_gitlab} performs the following steps and then commits the
 #' changes:
@@ -28,13 +30,25 @@
 #' For more details, read the documentation provided by
 #' \href{https://docs.gitlab.com/ee/ci/yaml/README.html#pages}{GitLab Pages}.
 #'
-#' @param username character (default: NULL). The GitLab username for the remote
-#'   repository. If not specified, workflowr will attempt to guess this from the
-#'   current remote named "origin" if it had previously been configured.
+#' @param username character (default: NULL). The GitLab account associated with
+#'   the GitLab repository. This is likely your personal GitLab username, but it
+#'   could also be the name of a GitLab organization you belong to. It will be
+#'   combined with the arguments \code{repository} and \code{domain} to
+#'   determine the URL of the new repository, e.g. the default is
+#'   https://gitlab.com/username/repository. It will be combined with the
+#'   arguments \code{repository}, \code{domain}, and \code{protocol} to
+#'   determine the URL for Git to use to push and pull from GitLab, e.g. the
+#'   default is https://gitlab.com/username/repository.git. If \code{username}
+#'   is not specified, \code{wflow_use_gitlab} will first attempt to guess it
+#'   from the current setting for the remote URL named "origin". If you haven't
+#'   previously configured a remote for this workflowr project (or you are
+#'   unsure what that means), then you should specify your GitLab username when
+#'   calling this function.
 #' @param repository character (default: NULL). The name of the remote
-#'   repository on GitLab. If not specified, workflowr will attempt to guess
-#'   this from the current remote named "origin" if it had previously been
-#'   configured.
+#'   repository on GitLab. If not specified, workflowr will guess the name of
+#'   the repository. First, it will check the current setting for the remote URL
+#'   named "origin". Second, it will use the name of the root directory of the
+#'   workflowr project.
 #' @param navbar_link logical (default: TRUE). Insert a link to the GitLab
 #'   repository into the navigation bar.
 #' @param protocol character (default: "https"). The protocol for communicating
@@ -92,23 +106,6 @@ wflow_use_gitlab <- function(username = NULL, repository = NULL,
 
   project <- absolute(project)
 
-  # If username and/or repository are NULL, make sure that it can be guessed
-  # from current remote "origin"
-  host <- get_host_from_remote(path = project)
-  if (is.null(username) || is.null(repository)) {
-    if (is.na(host)) {
-      stop("You must specify the arguments username and repository.")
-    } else {
-      host_parts <- stringr::str_split(host, "/")[[1]]
-      username <- host_parts[length(host_parts) - 1]
-      repository <- host_parts[length(host_parts)]
-      message("username: ", username)
-      message("respository: ", repository)
-    }
-  }
-
-  message("Summary from wflow_use_gitlab():")
-
   # Status ---------------------------------------------------------------------
 
   s <- wflow_status(project = project)
@@ -119,6 +116,33 @@ wflow_use_gitlab <- function(username = NULL, repository = NULL,
   r <- git2r::repository(path = s$git)
   remotes <- wflow_git_remote(verbose = FALSE, project = project)
 
+  message("Summary from wflow_use_gitlab():")
+
+  # Determine username and repository ------------------------------------------
+
+  # guess based on current remote "origin"
+  host <- get_host_from_remote(path = project) # returns NA if unavailable
+  host_parts <- stringr::str_split(host, "/")[[1]]
+
+  if (is.null(username)) {
+    if (is.na(host)) {
+      stop("Unable to guess username. Please specify this argument.")
+    } else {
+      username <- host_parts[length(host_parts) - 1]
+    }
+  }
+  message("username: ", username)
+
+  if (is.null(repository)) {
+    if (is.na(host)) {
+      # Use root directory name
+      repository <- fs::path_file(absolute(s$root))
+    } else {
+      repository <- host_parts[length(host_parts)]
+    }
+  }
+  message("respository: ", repository)
+
   # Rename docs/ to public/ ----------------------------------------------------
 
   if (basename(s$docs) == "public") {
@@ -214,13 +238,13 @@ wflow_use_gitlab <- function(username = NULL, repository = NULL,
 
   # Prepare output -------------------------------------------------------------
 
-  o <- list(renamed = renamed, files_git = files_git, commit = commit,
+  o <- list(username = username, repository = repository,
+            renamed = renamed, files_git = files_git, commit = commit,
             config_remote = config_remote)
   class(o) <- "wflow_use_gitlab"
 
-  message("\nGitLab configuration successful!\n")
-  message("To do: Create new repository at ", domain)
   message("To do: Run wflow_git_push() to send your project to GitLab")
+  message("Note: The push will create the new repository if it doesn't exist yet")
 
   return(invisible(o))
 }
