@@ -3,6 +3,10 @@ file.create("system-info.Rout.save")
 Sys.info()
 .Platform
 sessionInfo()
+# Dates and times
+Sys.Date()
+Sys.time()
+Sys.timezone()
 # Paths
 getwd()
 tempdir()
@@ -13,3 +17,6 @@ normalizePath("/")
 Sys.which("pandoc")
 rmarkdown::pandoc_available()
 rmarkdown::pandoc_version()
+# Git
+Sys.which("git")
+if (file.exists(Sys.which("git"))) system("git --version")
