@@ -23,7 +23,7 @@ test_that("wflow_git_commit can commit one new file", {
   expect_silent(actual <- wflow_git_commit(f1, project = site_dir))
   expect_true(f1 %in% actual$commit_files)
   recent <- commits(r, n = 1)[[1]]
-  expect_identical(git2r_slot(actual$commit, "sha"), git2r_slot(recent, "sha"))
+  expect_identical(actual$commit$sha, recent$sha)
   actual_print <- paste(utils::capture.output(actual), collapse = "\n")
   expect_true(grepl(sprintf("\\$ git add %s", f1), actual_print))
 })
@@ -35,7 +35,7 @@ test_that("wflow_git_commit can commit multiple new files", {
   expect_silent(actual <- wflow_git_commit(c(f2, f3), project = site_dir))
   expect_identical(actual$commit_files, c(f2, f3))
   recent <- commits(r, n = 1)[[1]]
-  expect_identical(git2r_slot(actual$commit, "sha"), git2r_slot(recent, "sha"))
+  expect_identical(actual$commit$sha, recent$sha)
   actual_print <- paste(utils::capture.output(actual), collapse = "\n")
   expect_true(grepl(sprintf("\\$ git add %s %s", f2, f3), actual_print))
 })
@@ -74,7 +74,7 @@ test_that("wflow_git_commit can commit all tracked files", {
   expect_silent(actual <- wflow_git_commit(all = TRUE, project = site_dir))
   expect_identical(actual$commit_files, tracked)
   recent <- commits(r, n = 1)[[1]]
-  expect_identical(git2r_slot(actual$commit, "sha"), git2r_slot(recent, "sha"))
+  expect_identical(actual$commit$sha, recent$sha)
 })
 
 test_that("wflow_git_commit does not affect Git repo if `dry_run = TRUE`", {
@@ -99,7 +99,7 @@ test_that("wflow_git_commit can perform the initial commit", {
 
   r <- init(x)
   config(r, user.name = "Test Name", user.email = "test@email")
-  o <- wflow_git_commit(c("*", ".gitignore", ".Rprofile"),
+  o <- wflow_git_commit(c("*", ".gitattributes", ".gitignore", ".Rprofile"),
                         message = "Initial commit", project = x)
   expect_equal(length(commits(r)), 1)
   s <- status(r)
@@ -216,7 +216,7 @@ test_that("wflow_git_commit throws an error if user.name and user.email are not
                "wflow_git_commit")
 })
 
-test_that("wflow_git_commit fails early if merge conflicts detected", {
+test_that("wflow_git_commit fails early if merge conflicts detected in Rmd file", {
   x <- tempfile("test-merge-conflicts-")
   suppressMessages(wflow_start(x, change_wd = FALSE, user.name = "Test Name",
                                user.email = "test@email"))
@@ -237,12 +237,43 @@ test_that("wflow_git_commit fails early if merge conflicts detected", {
   add(r, rmd)
   commit(r, "edit index.Rmd on master")
   # Generate merge conflict
-  workflowr:::git2r_merge(r, "b2")
+  workflowr:::git2r_merge(r, "b2", fail = FALSE)
 
   skip_on_cran()
 
   # Attempt to publish
-  expect_error(wflow_publish(rmd, project = x), rmd)
+  expect_error(wflow_publish(rmd, view = FALSE, project = x), rmd)
+})
+
+
+test_that("wflow_git_commit fails early if merge conflicts detected in non-Rmd file", {
+  x <- tempfile("test-merge-conflicts-")
+  suppressMessages(wflow_start(x, change_wd = FALSE, user.name = "Test Name",
+                               user.email = "test@email"))
+  x <- workflowr:::relative(x)
+  on.exit(unlink(x, recursive = TRUE, force = TRUE))
+  r <- repository(path = x)
+  s <- wflow_status(project = x)
+  rmd <- file.path(s$analysis, "index.Rmd")
+
+  # Edit non-Rmd file on new branch
+  non_rmd <- file.path(s$root, "test.txt")
+  checkout(r, "b2", create = TRUE)
+  cat("\nedit on b2\n", file = non_rmd, append = TRUE)
+  add(r, non_rmd)
+  commit(r, "edit non-Rmd on b2")
+  # Edit non-Rmd file on master branch
+  checkout(r, "master")
+  cat("\nedit on master\n", file = non_rmd, append = TRUE)
+  add(r, non_rmd)
+  commit(r, "edit non-Rmd on master")
+  # Generate merge conflict
+  workflowr:::git2r_merge(r, "b2", fail = FALSE)
+
+  skip_on_cran()
+
+  # Attempt to publish
+  expect_error(wflow_publish(rmd, view = FALSE, project = x), non_rmd)
 })
 
 test_that("wflow_git_commit fails if Git repository is locked", {
@@ -251,8 +282,9 @@ test_that("wflow_git_commit fails if Git repository is locked", {
   fs::file_create(file_to_commit)
   on.exit(wflow_remove(file_to_commit, project = site_dir))
 
-  index_lock <- file.path(workflowr:::git2r_workdir(r), ".git/index.lock")
+  index_lock <- file.path(git2r::workdir(r), ".git/index.lock")
   fs::file_create(index_lock)
+  index_lock <- workflowr:::absolute(index_lock)
 
   expect_error(wflow_git_commit(file_to_commit, project = site_dir),
                "The Git repository is locked")
