@@ -10,6 +10,9 @@ site_dir <- workflowr:::relative(site_dir)
 # Cleanup
 on.exit(unlink(site_dir, recursive = TRUE, force = TRUE))
 
+# Note: Only a few tests in this file use the modern setup
+source("setup.R")
+
 # Test wflow_status ------------------------------------------------------------
 
 s <- wflow_status(project = site_dir)
@@ -255,6 +258,15 @@ test_that("wflow_status throws error if no _site.yml file.", {
                "Unable to find the file _site.yml in the analysis directory.")
 })
 
+test_that("wflow_status throws error if no index.Rmd file.", {
+  index_original <- file.path(site_dir, "analysis/index.Rmd")
+  index_replace <-  file.path(site_dir, "analysis/other.Rmd")
+  on.exit(file.rename(index_replace, index_original))
+  file.rename(index_original, index_replace)
+  expect_error(s <- wflow_status(project = site_dir),
+               "Invalid workflowr project")
+})
+
 test_that("wflow_status throws error if no Git repository.", {
   git_original <- file.path(site_dir, ".git")
   git_replace <-  file.path(site_dir, ".git2")
@@ -326,3 +338,65 @@ test_that("wflow_paths does *not* throw warning if docs/ directory is missing",
   file.rename(docs, docs_tmp)
   expect_silent(wflow_paths(project = site_dir))
 })
+
+# Test print.wflow_status ------------------------------------------------------
+
+test_that("wflow_status includes Git status by default", {
+
+  # Setup functions from setup.R
+  path <- test_setup()
+  on.exit(test_teardown(path))
+
+  status <- wflow_status(project = path)
+  status_print <- utils::capture.output(print(status))
+  expect_true("The current Git status is: working directory clean" %in% status_print)
+
+  # modify a file in docs/. Status should not change
+  fs::file_create(file.path(status$docs, "generated.txt"))
+
+  status <- wflow_status(project = path)
+  status_print <- utils::capture.output(print(status))
+  expect_true("The current Git status is: working directory clean" %in% status_print)
+
+  # Add a file in analysis/. Status should be untracked
+  rmd <- file.path(status$analysis, "new.Rmd")
+  fs::file_create(rmd)
+  # Edit existing file. Status should be modified
+  index <- file.path(status$analysis, "index.Rmd")
+  cat("Edit\n", file = index, append = TRUE)
+
+  status <- wflow_status(project = path)
+  status_print <- utils::capture.output(print(status))
+  expect_true("The current Git status is:" %in% status_print)
+  expect_true(sum(
+    stringr::str_detect(status_print,
+                        glue::glue("\\s+untracked\\s+untracked\\s+{rmd}"))) == 1)
+  expect_true(sum(
+    stringr::str_detect(status_print,
+                        glue::glue("\\s+unstaged\\s+modified\\s+{index}"))) == 1)
+})
+
+test_that("wflow_status can omit Git status", {
+
+  # Setup functions from setup.R
+  path <- test_setup()
+  on.exit(test_teardown(path))
+
+  status <- wflow_status(include_git_status = FALSE, project = path)
+  status_print <- utils::capture.output(print(status))
+  expect_false("The current Git status is:" %in% status_print)
+
+  # modify a file in docs/. Status should not change
+  fs::file_create(file.path(status$docs, "generated.txt"))
+
+  status <- wflow_status(include_git_status = FALSE, project = path)
+  status_print <- utils::capture.output(print(status))
+  expect_false("The current Git status is:" %in% status_print)
+
+  # modify a file in analysis/. Status should change
+  fs::file_create(file.path(status$analysis, "new.Rmd"))
+
+  status <- wflow_status(include_git_status = FALSE, project = path)
+  status_print <- utils::capture.output(print(status))
+  expect_false("The current Git status is:" %in% status_print)
+})
